const path = require('path');
const MiniCssExtractPlugin = require('mini-css-extract-plugin');
const autoprefixer = require('autoprefixer');

const { getBabelConfig } = require('@talend/scripts-config-babel/babel-resolver');

const tsConfigExists = require('./utils/ts-config-exists');

module.exports = () => {
	const useTypescript = tsConfigExists();

	return env => {
		const name = (env && env.umd) || 'Talend';
		const optimize = !!(env && env.optimize);
		return {
			mode: 'production',
			optimization: {
				minimize: optimize,
			},
			entry: './src/index.js',
			output: {
				path: path.join(process.cwd(), './dist'),
				filename: optimize ? `${name}.min.js` : `${name}.js`,
				library: name,
				libraryTarget: 'umd',
			},
			resolve: {
				extensions: ['.js', useTypescript && '.ts', useTypescript && '.tsx'].filter(Boolean),
			},
			module: {
				rules: [
					{
						test: useTypescript ? /\.(js|ts|tsx)$/ : /\.js$/,
						exclude: /node_modules/,
						use: [
							{ loader: 'cache-loader' },
							{
								loader: 'babel-loader',
								options: getBabelConfig(),
							},
							useTypescript && {
								loader: 'ts-loader',
								options: {
									// disable type checker - it is done in another process by ForkTsCheckerWebpackPlugin
									transpileOnly: true,
								},
							},
						].filter(Boolean),
					},
					{
						test: /\.scss$/,
						use: [
							{ loader: MiniCssExtractPlugin.loader },
							{
								loader: 'css-loader',
								options: {
									sourceMap: !!optimize,
									modules: {
										localIdentName: '[name]__[local]___[hash:base64:5]',
									},
									importLoaders: 1,
								},
							},
							{
								loader: 'postcss-loader',
								options: {
									sourceMap: !!optimize,
									plugins: () => [autoprefixer()],
								},
							},
							{ loader: 'resolve-url-loader' },
							{
								loader: 'sass-loader',
								options: {
									sourceMap: !!optimize,
									prependData: "@import '~@talend/bootstrap-theme/src/theme/guidelines';",
								},
							},
						],
					},
					{
						test: /\.css$/,
						use: [
							{ loader: MiniCssExtractPlugin.loader },
							{ loader: 'css-loader' },
							{ loader: 'postcss-loader', options: { plugins: () => [autoprefixer()] } },
							{ loader: 'resolve-url-loader' },
						],
					},
					{
						test: /\.svg$/,
						loader: 'url-loader',
						options: {
							name: 'assets/svg/[name].[ext]',
							mimetype: 'image/svg+xml',
						},
					},
				],
			},
			externals: {
				react: 'React',
				'react-dom': 'ReactDOM',
				'react-i18next': 'ReactI18next',
				'@talend/react-components': 'TalendReactComponents',
			},
			node: {
				fs: 'empty',
			},
			plugins: [
				new MiniCssExtractPlugin({
					filename: `${name}.css`,
					chunkFilename: `${name}.css`,
				}),
			],
		};
	};
};
